@@ -223,6 +223,8 @@ def get_formatted_messages(formats, label, context):
         # conditionally turn off autoescaping for .txt extensions in format
         if format.endswith(".txt"):
             context.autoescape = False
+        else:
+            context.autoescape = True
         format_templates[format] = render_to_string((
             'notification/%s/%s' % (label, format),
             'notification/%s' % format), context_instance=context)
@@ -381,17 +383,9 @@ class ObservedItem(models.Model):
         verbose_name = _('observed item')
         verbose_name_plural = _('observed items')
 
-    def send_notice(self, extra_context=None):
-
-        if extra_context is None:
-            extra_context = {}
-
-        context = {
-            "observed": self.observed_object,
-        }
-        context.update(extra_context)
-
-        send([self.user], self.notice_type.label, context)
+    def send_notice(self):
+        send([self.user], self.notice_type.label,
+             {'observed': self.observed_object})
 
 
 def observe(observed, observer, notice_type_label, signal='post_save'):
@@ -413,13 +407,13 @@ def stop_observing(observed, observer, signal='post_save'):
     observed_item = ObservedItem.objects.get_for(observed, observer, signal)
     observed_item.delete()
 
-def send_observation_notices_for(observed, signal='post_save', extra_context=None):
+def send_observation_notices_for(observed, signal='post_save'):
     """
     Send a notice for each registered user about an observed object.
     """
     observed_items = ObservedItem.objects.all_for(observed, signal)
     for observed_item in observed_items:
-        observed_item.send_notice(extra_context)
+        observed_item.send_notice()
     return observed_items
 
 def is_observing(observed, observer, signal='post_save'):
